/**
  *  \file loaderstate.h
  *  \brief LoaderState class declaration
  *  \author Stefan Reuther
  */
#ifndef LOADERSTATE_H_INCLUDED
#define LOADERSTATE_H_INCLUDED

#include <string>

/** Manages state and permissions of loader. This object keeps track
    of things that are allowed in a file, and counts them. For
    example, LoaderState can be configured to allow only game
    definitions, not program definitions, in a game definition file
    downloaded from a server.

    In addition, it supports use of relative path names. */
class LoaderState {
 public:
    /** Kinds of items under access control. */
    enum What {
        Globals,       /**< Global configuration items. */
        Games,         /**< Game definitions. */
        Programs       /**< Program definitions. */
    };

    LoaderState();

    ~LoaderState();

    void start();

    void setAccept(What what, bool allow);

    void setAcceptAll();

    bool isAccept(What what);

    void setBaseDirectory(std::string dir);

    std::string expandDirectory(std::string dir);

    int getNumItems(What what);

    bool isAcceptAny();

 private:
    enum { MAX = 3 };
    bool m_Accept[MAX];
    int  m_Count[MAX];

    std::string m_Basedir;
};

#endif
