/**
  *  \file osdep.cpp
  */

#include <cstdlib>
#include <fstream>
#include "osdep.h"

/** Extract path of a file name. */
std::string
getDirectoryName(std::string s)
{
    std::string::size_type n = s.rfind('/');
    if (n == s.npos)
        return std::string("");
    return s.substr(0, n);
}

std::string
getBaseName(std::string s)
{
    std::string::size_type n = s.rfind('/');
    if (n == s.npos)
        return s;
    return s.substr(n);
}

/** Make file name. Returns the file name that will be accessed when
    we open \c name while sitting in working directory \c basedir. */
std::string
makeFileName(std::string basedir, std::string name)
{
    if (name.size() == 0)
        return basedir;

    if (name[0] == '/')
        return name;

    if (basedir.size() != 0 && basedir[basedir.size()-1] != '/')
        basedir += "/";

    return basedir + name;
}

std::string
getSettingsFileName()
{
    const char* p = std::getenv("HOME");
    if (p) {
        return makeFileName(p, ".vgapintegrator");
    } else {
        return ".vgapintegrator";
    }
}

bool
isExistingFileName(std::string name)
{
    std::ifstream in(name.c_str());
    return in;
}
