/**
  *  \file osdep.cpp
  */

#include <cstdlib>
#include <fstream>
#include <ctype.h>
#include "osdep.h"

/** Extract path of a file name. */
std::string
getDirectoryName(std::string s)
{
    std::string::size_type n = s.find_last_of("/\\:");
    if (n == s.npos)
        return std::string("");
    return s.substr(0, n);
}

std::string
getBaseName(std::string s)
{
    std::string::size_type n = s.find_last_of("/\\:");
    if (n == s.npos)
        return s;
    return s.substr(n);
}

static void
splitDrive(std::string& dir, std::string& drive)
{
    if (dir.size() >= 2 && dir[1] == ':') {
        drive.assign(dir, 0, 2);
        drive[0] = toupper((unsigned char) drive[0]);
        dir.erase(0, 2);
    }
}

static bool
isSlash(char c)
{
    return c == '/' || c == '\\';
}

/** Make file name. Returns the file name that will be accessed when
    we open \c name while sitting in working directory \c basedir. */
std::string
makeFileName(std::string basedir, std::string name)
{
    if (name.size() == 0)
        return basedir;

    if (basedir.size() == 0)
        return name;

    std::string basedrive, namedrive;
    splitDrive(basedir, basedrive);
    splitDrive(name, namedrive);

    /* In case name doesn't have a drive, copy it */
    if (namedrive.size() == 0)
        namedrive = basedrive;

    if (name.size() && isSlash(name[0])) {
        /* x:\foo, \foo */
        return namedrive + name;
    }

    if (namedrive == basedrive || namedrive.size() == 0) {
        /* x:foo, foo */
        if (basedir.empty() || !isSlash(basedir[basedir.size()-1]))
            basedir.append("\\");
        return basedrive + basedir + name;
    }

    /* we're here if both specified different drives, but name is not
       absolute. In this case, make it absolute. */
    return namedrive + "\\" + name;
}

std::string
getSettingsFileName()
{
    const char* p = std::getenv("APPDATA");
    if (p) {
        return makeFileName(p, ".vgapintegrator");
    } else {
        return ".vgapintegrator";
    }
}

bool
isExistingFileName(std::string name)
{
    std::ifstream in(name.c_str());
    return in;
}
